Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/monadc/__init__.py | 10 | 0 | 0 | 100%
src/monadc/decorators.py | 33 | 0 | 3 | 100%
src/monadc/either/__init__.py | 4 | 0 | 0 | 100%
src/monadc/either/either.py | 76 | 25 | 0 | 67%
src/monadc/either/left.py | 88 | 0 | 0 | 100%
src/monadc/either/right.py | 84 | 0 | 0 | 100%
src/monadc/option/__init__.py | 4 | 0 | 0 | 100%
src/monadc/option/nil.py | 119 | 3 | 0 | 97%
src/monadc/option/option.py | 110 | 44 | 0 | 60%
src/monadc/option/some.py | 133 | 5 | 0 | 96%
src/monadc/result/__init__.py | 4 | 0 | 0 | 100%
src/monadc/result/err.py | 75 | 0 | 0 | 100%
src/monadc/result/ok.py | 79 | 0 | 0 | 100%
src/monadc/result/result.py | 62 | 23 | 0 | 63%
src/monadc/try_/__init__.py | 4 | 0 | 0 | 100%
src/monadc/try_/failure.py | 79 | 2 | 0 | 97%
src/monadc/try_/success.py | 80 | 0 | 0 | 100%
src/monadc/try_/try_.py | 55 | 15 | 0 | 73%
src/monadc/utils.py | 23 | 0 | 0 | 100%
Total | 1122 | 117 | 3 | 90%

No items found using the specified filter.